@@ -97,9 +97,7 @@ class RetrieveModelMixin(object):
     Should be mixed in with `SingleObjectAPIView`.
     """
     def retrieve(self, request, *args, **kwargs):
-        queryset = self.get_queryset()
-        filtered_queryset = self.filter_queryset(queryset)
-        self.object = self.get_object(filtered_queryset)
+        self.object = self.get_object()
         serializer = self.get_serializer(self.object)
         return Response(serializer.data)
 
